@@ -1,4 +1,4 @@
-// Copyright 2009-2020 Intel Corporation
+// Copyright 2009-2021 Intel Corporation
 // SPDX-License-Identifier: Apache-2.0
 
 #pragma once
@@ -53,14 +53,14 @@ namespace embree
         return accel->pointQuery(query, context);
       }
 
-      template<int Nx, bool robust>
-        static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHit& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+      template<bool robust>
+        static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHit& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
       {
-        BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+        BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
         for (size_t i=0;i<num;i++)
         {
-          vfloat<Nx> dist;
+          vfloat<N> dist;
           size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
 #if defined(__AVX__)
           STAT3(normal.trav_hit_boxes[popcnt(mask)],1,1,1);
@@ -75,15 +75,15 @@ namespace embree
           }
         }
       }
-      template<int Nx, bool robust>        
-        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, Ray& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+      template<bool robust>        
+        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, Ray& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
 
       {
-        BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+        BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
         for (size_t i=0;i<num;i++)
         {
-          vfloat<Nx> dist;
+          vfloat<N> dist;
           size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
           while(mask != 0)
           {
@@ -155,14 +155,14 @@ namespace embree
         return accel->pointQuery(query, context);
       }
 
-      template<int Nx, bool robust>
-        static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHit& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+      template<bool robust>
+        static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHit& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
       {
-        BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+        BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
         for (size_t i=0;i<num;i++)
         {
-          vfloat<Nx> dist;
+          vfloat<N> dist;
           size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
 #if defined(__AVX__)
           STAT3(normal.trav_hit_boxes[popcnt(mask)],1,1,1);
@@ -178,14 +178,14 @@ namespace embree
         }
       }
 
-      template<int Nx, bool robust>        
-        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, Ray& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+      template<bool robust>        
+        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, Ray& ray, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
       {
-        BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+        BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
         for (size_t i=0;i<num;i++)
         {
-          vfloat<Nx> dist;
+          vfloat<N> dist;
           size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
           while(mask != 0)
           {
@@ -326,14 +326,14 @@ namespace embree
           return !valid0;
         }
         
-        template<int Nx, bool robust>        
-          static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+        template<bool robust>        
+          static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
         {
-          BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+          BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
           for (size_t i=0;i<num;i++)
           {
-            vfloat<Nx> dist;
+            vfloat<N> dist;
             size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
             while(mask != 0)
             {
@@ -346,14 +346,14 @@ namespace embree
           }
         }
         
-        template<int Nx, bool robust>
-        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+        template<bool robust>
+        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
         {
-          BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+          BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
           for (size_t i=0;i<num;i++)
           {
-            vfloat<Nx> dist;
+            vfloat<N> dist;
             size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
             while(mask != 0)
             {
@@ -408,7 +408,9 @@ namespace embree
           const Vec3vf<K> p2 = vtx[i*4+2];
           const Vec3vf<K> p3 = vtx[i*4+3];
           STAT3(shadow.trav_prims,1,popcnt(valid0),K);
-          if (pre.intersectK(valid0,ray,p0,p1,p2,p3,g,subgrid,i,OccludedKEpilogM<4,K,filter>(valid0,ray,context,subgrid.geomID(),subgrid.primID(),i)))
+          //if (pre.intersectK(valid0,ray,p0,p1,p2,p3,g,subgrid,i,OccludedKEpilogM<4,K,filter>(valid0,ray,context,subgrid.geomID(),subgrid.primID(),i)))
+          if (pre.occludedK(valid0,ray,p0,p1,p2,p3,g,subgrid,i,OccludedKEpilogM<4,K,filter>(valid0,ray,context,subgrid.geomID(),subgrid.primID(),i)))
+	    
             break;
         }
         return !valid0;
@@ -470,14 +472,14 @@ namespace embree
           return !valid0;
         }
         
-        template<int Nx, bool robust>        
-          static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+        template<bool robust>        
+          static __forceinline void intersect(const Accel::Intersectors* This, Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
         {
-          BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+          BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
           for (size_t i=0;i<num;i++)
           {
-            vfloat<Nx> dist;
+            vfloat<N> dist;
             size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
             while(mask != 0)
             {
@@ -490,14 +492,14 @@ namespace embree
           }
         }
         
-        template<int Nx, bool robust>
-        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,Nx,robust> &tray, size_t& lazy_node)
+        template<bool robust>
+        static __forceinline bool occluded(const Accel::Intersectors* This, Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive* prim, size_t num, const TravRay<N,robust> &tray, size_t& lazy_node)
         {
-          BVHNQuantizedBaseNodeIntersector1<N,Nx,robust> isec1;
+          BVHNQuantizedBaseNodeIntersector1<N,robust> isec1;
 
           for (size_t i=0;i<num;i++)
           {
-            vfloat<Nx> dist;
+            vfloat<N> dist;
             size_t mask = isec1.intersect(&prim[i].qnode,tray,dist); 
             while(mask != 0)
             {
@@ -511,8 +513,5 @@ namespace embree
           return false;
         }
     };
-
-
-
   }
 }
