@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright 2009-2020 Intel Corporation
+## Copyright 2009-2021 Intel Corporation
 ## SPDX-License-Identifier: Apache-2.0
 
 # Embree Regression Test Script
@@ -76,7 +76,7 @@ builds = []
 ISAs_win  = ['SSE2', 'AVX', 'AVX2']
 #ISAs_unix = ['AVX2']
 #ISAs_unix = ['SSE2', 'AVX', 'AVX2']
-ISAs_unix = ['SSE2', 'AVX', 'AVX512KNL']
+ISAs_unix = ['SSE2', 'AVX', 'AVX512']
 ISAs = []
 
 supported_configurations = [
@@ -110,7 +110,6 @@ supported_configurations = [
   'ICC_x64_RelWithDebInfo_SSE4.2',
   'ICC_x64_RelWithDebInfo_AVX',
   'ICC_x64_RelWithDebInfo_AVX2',
-  'ICC_x64_RelWithDebInfo_AVX512KNL',
   
   'GCC_x64_RelWithDebInfo_SSE2',
   'GCC_x64_RelWithDebInfo_SSE4.2',
