@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2021 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -22,6 +9,8 @@
 #include "scene.h"
 #include "scene_device.h"
 
+#if defined(USE_GLFW)
+
 /* include GLFW for window management */
 #include <GLFW/glfw3.h>
 
@@ -29,6 +18,8 @@
 #include "../imgui/imgui.h"
 #include "../imgui/imgui_impl_glfw_gl2.h"
 
+#endif
+
 namespace embree
 {
   /* functions provided by each tutorial */
@@ -36,7 +27,7 @@ namespace embree
   extern "C" void device_resize(int width, int height);
   extern "C" void device_render(unsigned* pixels, const unsigned width, const unsigned height, const float time, const ISPCCamera& camera);
   extern "C" bool device_pick(const float x, const float y, const ISPCCamera& camera, Vec3fa& hitPos);
-  extern "C" void device_key_pressed (int key);
+  //extern "C" void device_key_pressed (int key);
   extern "C" void device_cleanup();
 
   template<typename Ty>
@@ -64,7 +55,8 @@ namespace embree
           num++;
         }
       }
-      return sum/Ty(num);
+      if (num == 0) return 0;
+      else return sum/Ty(num);
     }
 
     std::deque<std::pair<double,Ty>> values;
@@ -110,21 +102,34 @@ namespace embree
     /* set scene to use */
     void set_scene (TutorialScene* in);
 
+#if defined(USE_GLFW)
+    
+  public:
+    
     /* create a fullscreen window */
     GLFWwindow* createFullScreenWindow();
 
     /* create a standard window of specified size */
     GLFWwindow* createStandardWindow(int width, int height);
+
+    /* interactive rendering using GLFW window */
+    void renderInteractive();
  
     /* GLFW callback functions */
   public:
+    virtual void keypressed(int key);
     virtual void keyboardFunc(GLFWwindow* window, int key, int scancode, int action, int mods);
     virtual void clickFunc(GLFWwindow* window, int button, int action, int mods);
     virtual void motionFunc(GLFWwindow* window, double x, double y);
     virtual void displayFunc();
     virtual void reshapeFunc(GLFWwindow* window, int width, int height);
-    virtual void drawGUI() {}; 
+    virtual void drawGUI() {};
 
+  public:
+    GLFWwindow* window = nullptr;
+
+#endif
+    
   public:
     virtual void render(unsigned* pixels, const unsigned width, const unsigned height, const float time, const ISPCCamera& camera);
   
@@ -155,8 +160,7 @@ namespace embree
 
     unsigned window_width;
     unsigned window_height;
-    GLFWwindow* window;
-
+  
     double time0;
     int debug_int0;
     int debug_int1;
